@@ -128,6 +128,9 @@ FAILEDOPERATION_GETCLSMACHINEGROUPCONFIGS = 'FailedOperation.GetClsMachineGroupC
 # 获取CLS日志主题失败。
 FAILEDOPERATION_GETCLSTOPIC = 'FailedOperation.GetClsTopic'
 
+# 获取集群失败
+FAILEDOPERATION_GETCLUSTERFAILED = 'FailedOperation.GetClusterFailed'
+
 # Kubernetes client建立失败。
 FAILEDOPERATION_K8SCLIENTBUILDERROR = 'FailedOperation.K8sClientBuildError'
 
@@ -137,6 +140,9 @@ FAILEDOPERATION_KUBECLIENTCONF = 'FailedOperation.KubeClientConf'
 # 连接用户Kubernetes集群失败。
 FAILEDOPERATION_KUBECLIENTCONNECTION = 'FailedOperation.KubeClientConnection'
 
+# 创建kube client失败
+FAILEDOPERATION_KUBECLIENTCREATE = 'FailedOperation.KubeClientCreate'
+
 # KubernetesAPI错误。
 FAILEDOPERATION_KUBECOMMON = 'FailedOperation.KubeCommon'
 
@@ -404,7 +410,7 @@ INTERNALERROR_NOTVERIFIED = 'InternalError.NotVerified'
 # 镜像OS不支持。
 INTERNALERROR_OSNOTSUPPORT = 'InternalError.OsNotSupport'
 
-# Param。
+# 参数错误。
 INTERNALERROR_PARAM = 'InternalError.Param'
 
 # Pod未找到。
